==> tellico_3.1.2.orig.tar.xz: tellico-3.1.2/src/gui/tabwidget.cpp <==
/***************************************************************************
    Copyright (C) 2002-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#include "tabwidget.h"

#include <QTabBar>

using Tellico::GUI::TabWidget;

TabWidget::TabWidget(QWidget* parent_)
    : QTabWidget(parent_) {
}

void TabWidget::setFocusToFirstChild() {
  QWidget* page = currentWidget();
  Q_ASSERT(page);
  QList<QWidget*> list = page->findChildren<QWidget*>();
  foreach(QWidget* w, list) {
    if(w->focusPolicy() != Qt::NoFocus) {
      w->setFocus();
      break;
    }
  }
}

void TabWidget::setTabBarHidden(bool hide_) {
  QTabBar* tabBar = findChild<QTabBar *>();
  Q_ASSERT(tabBar);
  tabBar->setHidden(hide_);
}

==> tellico_4.1.3.orig.tar.xz: tellico-4.1.3/src/gui/tabwidget.cpp <==
/***************************************************************************
    Copyright (C) 2002-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#include "tabwidget.h"

#include <QTabBar>

using Tellico::GUI::TabWidget;

TabWidget::TabWidget(QWidget* parent_)
    : QTabWidget(parent_) {
}

void TabWidget::setFocusToFirstChild() {
  QWidget* page = currentWidget();
  Q_ASSERT(page);
  QList<QWidget*> list = page->findChildren<QWidget*>();
  foreach(QWidget* w, list) {
    if(!w->isHidden() && w->focusPolicy() != Qt::NoFocus) {
      w->setFocus();
      break;
    }
  }
}

void TabWidget::setTabBarHidden(bool hide_) {
  QTabBar* tabBar = findChild<QTabBar *>();
  Q_ASSERT(tabBar);
  tabBar->setHidden(hide_);
}
